@@ -1,4 +1,4 @@
-from .faceted import faceted, faceted_ax
+from .faceted import faceted, faceted_ax  # noqa: F401
 from ._version import get_versions
 
 __version__ = get_versions()["version"]
